@@ -14,9 +14,9 @@ const PlotlyChart = {
                 let x = JSON.parse(this.graph.json);
                 x.responsive = true;
                 Plotly.react(this.graph.id, x);
+                window.dispatchEvent(new Event('resize'))
             }
-        }
-        );
+        });
     },
     updated() {
         this.$nextTick(function () {
@@ -33,10 +33,10 @@ const PlotlyChart = {
 
 const interventionTableConfig = {
     social_distance: {
-        formTitle: "Social distancing",
+        formTitle: "Physical distancing",
         fields: [{key: 'start', type: 'number', label: 'Start day'},
             {key: 'end', type: 'number', label: 'End day'},
-            {label: 'Effectiveness', key: 'level', type: 'select', options: [{label: 'Aggressive effectiveness', value: 'aggressive'}, {label: 'Moderate effectiveness', value: 'moderate'}, {label: 'Mild effectiveness', value: 'mild'}]}],
+            {label: 'Effectiveness', key: 'level', type: 'select', options: [{label: 'Aggressive (80%)', value: 'aggressive'}, {label: 'Moderate (50%)', value: 'moderate'}, {label: 'Mild (20%)', value: 'mild'}]}],
         handleSubmit: function(event) {
             const start = parseInt(event.target.elements.start.value);
             const end = parseInt(event.target.elements.end.value);
@@ -169,13 +169,14 @@ var vm = new Vue({
             interventionTableConfig,
             running: false,
             errs: [],
-            reset_options: ['Example'],//, 'Seattle', 'Wuhan', 'Global'],
-            reset_choice: 'Example'
+            reset_options: ['Default', 'Optimistic', 'Pessimistic'],
+            reset_choice: 'Default'
         };
     },
 
-    async created() {
+    created() {
         this.get_version();
+        this.get_location_options();
         this.resetPars();
         this.watchSimLengthParam();
         this.get_licenses();
@@ -206,7 +207,7 @@ var vm = new Vue({
                 this.$set(this.int_pars, key, []);
             }
             // validate intervention
-            const notValid = !intervention.end || !intervention.start || intervention.end <= intervention.start
+            const notValid = !intervention.end || intervention.start < 0 || intervention.end <= intervention.start
             if (notValid) {
                 this.$set(this.scenarioError, scenarioKey, `Please enter a valid day range`);
                 return;
@@ -242,12 +243,7 @@ var vm = new Vue({
             const response = await sciris.rpc('get_gantt', undefined, {int_pars: this.int_pars, intervention_config: this.interventionTableConfig});
             this.intervention_figs = response.data;
         },
-        open_panel() {
-            this.panel_open = true;
-        },
-        close_panel() {
-            this.panel_open = false;
-        },
+
         resize_start() {
             this.resizing = true;
         },
@@ -263,15 +259,27 @@ var vm = new Vue({
             }
         },
 
+        dispatch_resize(){
+            window.dispatchEvent(new Event('resize'))
+        },
         async get_version() {
             const response = await sciris.rpc('get_version');
             this.app.version = response.data;
         },
-        async get_licenses(){
+
+        async get_location_options() {
+            let response = await sciris.rpc('get_location_options');
+            for (let country of response.data) {
+                this.reset_options.push(country);
+            }
+        },
+
+        async get_licenses() {
             const response = await sciris.rpc('get_licenses');
             this.app.license = response.data.license;
             this.app.notice = response.data.notice;
         },
+
         async runSim() {
             this.running = true;
             // this.graphs = this.$options.data().graphs; // Uncomment this to clear the graphs on each run
@@ -290,7 +298,8 @@ var vm = new Vue({
                     int_pars: this.int_pars,
                     datafile: this.datafile.server_path,
                     show_animation: this.show_animation,
-                    n_days: this.sim_length.best
+                    n_days: this.sim_length.best,
+                    location: this.reset_choice
                 }
                 console.log('run_sim: ', kwargs);
                 const response = await sciris.rpc('run_sim', undefined, kwargs);
@@ -298,11 +307,11 @@ var vm = new Vue({
                 this.result.files = response.data.files;
                 this.result.summary = response.data.summary;
                 this.errs = response.data.errs;
-                this.panel_open = this.errs.length > 0;
+                // this.panel_open = this.errs.length > 0; // Better solution would be to have a pin button
                 this.sim_pars = response.data.sim_pars;
                 this.epi_pars = response.data.epi_pars;
                 this.int_pars = response.data.int_pars;
-                this.history.push(JSON.parse(JSON.stringify({ sim_pars: this.sim_pars, epi_pars: this.epi_pars, int_pars: this.int_pars, result: this.result })));
+                this.history.push(JSON.parse(JSON.stringify({ sim_pars: this.sim_pars, epi_pars: this.epi_pars, reset_choice: this.reset_choice, int_pars: this.int_pars, result: this.result })));
                 this.historyIdx = this.history.length - 1;
 
             } catch (e) {
@@ -310,6 +319,7 @@ var vm = new Vue({
                     message: 'Unable to submit model.',
                     exception: `${e.constructor.name}: ${e.message}`
                 })
+                this.panel_open = true
             }
             this.running = false;
 
@@ -319,14 +329,15 @@ var vm = new Vue({
             const response = await sciris.rpc('get_defaults', [this.reset_choice]);
             this.sim_pars = response.data.sim_pars;
             this.epi_pars = response.data.epi_pars;
-            this.sim_length = {...this.sim_pars['n_days']}
+            this.sim_length = this.sim_pars['n_days'];
             this.int_pars = {};
             this.intervention_figs = {};
             this.setupFormWatcher('sim_pars');
             this.setupFormWatcher('epi_pars');
-            this.graphs = [];
+            // this.result.graphs = [];
             this.reset_datafile()
         },
+
         setupFormWatcher(paramKey) {
             const params = this[paramKey];
             if (!params) {
@@ -336,9 +347,11 @@ var vm = new Vue({
                 this.$watch(`${paramKey}.${key}`, this.validateParam(key), { deep: true });
             });
         },
+
         watchSimLengthParam() {
             this.$watch('sim_length', this.validateParam('sim_length'), { deep: true });
         },
+
         validateParam(key) {
             return (param) => {
                 if (param.best <= param.max && param.best >= param.min) {
@@ -373,7 +386,7 @@ var vm = new Vue({
                 this.sim_pars = response.data.sim_pars;
                 this.epi_pars = response.data.epi_pars;
                 this.int_pars = response.data.int_pars;
-                this.graphs = [];
+                this.result.graphs = [];
                 this.intervention_figs = {}
 
                 if (this.int_pars){
@@ -388,15 +401,18 @@ var vm = new Vue({
         upload_datafile: generate_upload_file_handler(function(filepath){
             vm.datafile.server_path = filepath
         }),
+
         reset_datafile() {
             this.datafile = {
                 local_path: null,
                 server_path: null
             }
         },
+
         loadPars() {
             this.sim_pars = this.history[this.historyIdx].sim_pars;
             this.epi_pars = this.history[this.historyIdx].epi_pars;
+            this.reset_choice = this.history[this.historyIdx].reset_choice;
             this.int_pars = this.history[this.historyIdx].int_pars;
             this.result = this.history[this.historyIdx].result;
         },
