@@ -13,22 +13,22 @@ do_plot = 1
 do_save = 0
 do_show = 1
 verbose = 1
-interv  = 0
+interv  = 1
 
 # Set filename if saving
 version  = 'v0'
-date     = '2020apr17'
+date     = '2020apr25'
 folder   = 'results'
 basename = f'{folder}/covasim_run_{date}_{version}'
 fig_path = f'{basename}.png'
 
 # Configure the sim -- can also just use a normal dictionary
 pars = sc.objdict(
-    pop_size     = 5000, # Population size
+    pop_size     = 10000, # Population size
     pop_infected = 10,     # Number of initial infections
-    n_days       = 60,   # Number of days to simulate
+    n_days       = 120,   # Number of days to simulate
     rand_seed    = 1,     # Random seed
-    pop_type     = 'random',
+    pop_type     = 'hybrid',
 )
 
 # Optionally add an intervention
